@@ -163,6 +163,21 @@ function select_range_do_options(){
             'refresh' => 0
         );
 
+        $optionValues[] = array(
+            'name' => 'select_range_multiple_gaps',
+            'caption' => _("When filling multiple gaps"),
+            'type' => SMOPT_TYPE_STRLIST,
+            'initial_value' => 
+                getPref($data_dir, $username, 'select_range_multiple_gaps', 'fill_all' ),
+            'posvals' => 
+                array( 
+                    'fill_all' => _("Fill all gaps"),
+                    'bottom_up' => _("Fill gaps from bottom up"),
+                    'top_down' => _("Fill gaps from top down")
+                ),
+            'refresh' => 0
+        );
+
         $showed_option = true;
     }
 
@@ -292,6 +307,7 @@ function select_range_get_prefs() {
 }
 
 function select_range_jscript_function( $safe_name, $alerts = 1, $context = '' ){
+    global $data_dir, $username;
     include_once( SM_PATH . 'functions/i18n.php' );
 
     global $select_range_already_printed_jscript;
@@ -316,6 +332,9 @@ function select_range_jscript_function( $safe_name, $alerts = 1, $context = '' )
     bindtextdomain('squirrelmail', SM_PATH . 'locale');
     textdomain('squirrelmail');
      
+    //options: 'fill_all' 'bottom_up' 'top_down'
+    $fill_type = getPref($data_dir, $username, 'select_range_multiple_gaps', 'fill_all' );
+
     $result = <<<EOF
 <script language="JavaScript" type="text/javascript">
 <!--
@@ -323,19 +342,118 @@ function doSelect(element, e){
   if( !e ) { 
     return; 
   }
+
   var shifted = 0;
   if( e.shiftKey || ( e.modifiers && ( e.modifiers & 4 ) ) ){ 
     shifted = 1;
   }
   if( shifted ){
+    var was_checked = 0;
     if( document.$form_name.elements[element].type == 'checkbox' ){
-      document.$form_name.elements[element].checked = true;
+      was_checked = !document.$form_name.elements[element].checked;
+    }
+    else{
+      return;
+    }
+
+    //get first and last checked message
+    var first_checked_message = -1;
+    var last_checked_message = -1; 
+    for (var i = 0; i < document.$form_name.elements.length; i++) {
+      if( document.$form_name.elements[i].type == 'checkbox' ) {
+        if( document.$form_name.elements[i].checked ){
+          if( first_checked_message == -1 ){
+            first_checked_message = i;
+          } else {
+            last_checked_message = i;
+          }
+        }
+      }
+    }
+
+    document.$form_name.elements[element].checked = true;
+    var checked_before_current = 0;
+    var checked_after_current = 0;
+    var fill_type = '$fill_type';
+
+    if( fill_type != "fill_all" ){
+
+      //if two messages are checked
+      if( ( first_checked_message > -1 ) && ( last_checked_message > -1 ) ){
+        
+        //get index number of current element
+        var element_index = 0;
+        for (var i = 0; i < document.$form_name.elements.length; i++) {
+          if( document.$form_name.elements[i].name == element ) {
+            element_index = i;
+            i = document.$form_name.elements.length + 1;
+          }
+        }
+
+        //if we are after the last checked element, we fill from the bottom up
+        if( element_index >= last_checked_message ){
+          fill_type = "bottom_up";
+          
+          //see if the element before this element was checked
+          for (var i = element_index - 1; i >= 0; i--) {
+            if( document.$form_name.elements[i].type == 'checkbox' ) {
+              if( document.$form_name.elements[i].checked ){
+                checked_before_current = 1;
+              }
+              i = -1;
+            }
+          }
+        }
+
+        //if we are before the first checked element, we fill from the top down
+        else if( element_index <= first_checked_message ){
+          fill_type = "top_down";
+
+          //see if the element after this element was checked
+          for (var i = element_index + 1; i <= document.$form_name.elements.length; i++) {
+            if( document.$form_name.elements[i].type == 'checkbox' ) {
+              if( document.$form_name.elements[i].checked ){
+                checked_after_current = 1;
+              }
+              i = document.$form_name.elements.length + 1;
+            }
+          }
+        }
+
+        //we are in between the first and last checked elements
+        //if we weren't checked, fill gaps above and below current element
+        else{
+          if( !was_checked ){
+            for (var i = element_index - 1; i >= 0; i--) {
+              if( document.$form_name.elements[i].checked ){
+                break;
+              }
+              document.$form_name.elements[i].checked = true;
+            }
+            for (var i = element_index + 1; i <= document.$form_name.elements.length; i++) {
+              if( document.$form_name.elements[i].checked ){
+                break;
+              }
+              document.$form_name.elements[i].checked = true;
+            }
+          }
+          return;
+        }
+      }
+    }
+
+    if( checked_before_current || checked_after_current ){
+      if( was_checked ){
+        $func_name( true, fill_type );
+      }
+    }
+    else{
+      $func_name( true, fill_type );
     }
-    $func_name( true );
   }
 }
 
-function $func_name( hide_alerts ) { 
+function $func_name( hide_alerts, fill_type ) { 
   var display_alert = $alerts;
   if( hide_alerts ){
     display_alert = false;
@@ -362,13 +480,57 @@ function $func_name( hide_alerts ) {
       }
     }
   }
+
   if( first_checked_message != -1 && last_checked_message != -1 ){
     if( checked_after_unchecked == 0 ){
       if( display_alert == 1 ){
         alert( "$at_least_one_item_between" );
       }
     } else {
-      for (var i = first_checked_message; i < last_checked_message; i++) {
+
+      var message_before_fill_gap = first_checked_message;
+      var message_after_fill_gap = last_checked_message;
+      if( !fill_type ){
+        fill_type = '$fill_type';
+      }
+      var in_gap = 0;
+
+      if( fill_type == 'bottom_up' ){
+        for (var i = last_checked_message; i > first_checked_message; i--) {
+          if( document.$form_name.elements[i].type == 'checkbox' ) {
+            if( in_gap ){
+              if( document.$form_name.elements[i].checked ){
+                message_before_fill_gap = i;
+                i = first_checked_message - 1;
+              }
+            } 
+            else{
+              if( !document.$form_name.elements[i].checked ){
+                in_gap = 1;
+              }
+            }
+          }
+        }
+      }
+      else if( fill_type == 'top_down' ){
+        for (var i = first_checked_message; i < last_checked_message; i++) {
+          if( document.$form_name.elements[i].type == 'checkbox' ) {
+            if( in_gap ){
+              if( document.$form_name.elements[i].checked ){
+                message_after_fill_gap = i;
+                i = last_checked_message + 1;
+              }
+            } 
+            else{
+              if( !document.$form_name.elements[i].checked ){
+                in_gap = 1;
+              }
+            }
+          }
+        }
+      }
+
+      for (var i = message_before_fill_gap; i < message_after_fill_gap; i++) {
         if( document.$form_name.elements[i].type == 'checkbox' ) {
           document.$form_name.elements[i].checked = true;
         }
